@@ -300,7 +300,11 @@ KCalendarCore::DateList MonthView::selectedIncidenceDates() const
 QDateTime MonthView::selectionStart() const
 {
     if (d->scene->selectedCell()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         return QDateTime(d->scene->selectedCell()->date());
+#else
+        return QDateTime(d->scene->selectedCell()->date().startOfDay());
+#endif
     } else {
         return QDateTime();
     }
@@ -361,9 +365,9 @@ void MonthView::updateView()
 void MonthView::wheelEvent(QWheelEvent *event)
 {
     // invert direction to get scroll-like behaviour
-    if (event->delta() > 0) {
+    if (event->angleDelta().y() > 0) {
         d->moveStartDate(-1, 0);
-    } else if (event->delta() < 0) {
+    } else if (event->angleDelta().y() < 0) {
         d->moveStartDate(1, 0);
     }
 
@@ -446,7 +450,12 @@ void MonthView::showDates(const QDate &start, const QDate &end, const QDate &pre
 
 QPair<QDateTime, QDateTime> MonthView::actualDateRange(const QDateTime &start, const QDateTime &, const QDate &preferredMonth) const
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QDateTime dayOne = preferredMonth.isValid() ? QDateTime(preferredMonth) : start;
+#else
+    QDateTime dayOne = preferredMonth.isValid() ? QDateTime(preferredMonth.startOfDay()) : start;
+#endif
+
     dayOne.setDate(QDate(dayOne.date().year(), dayOne.date().month(), 1));
     const int weekdayCol = (dayOne.date().dayOfWeek() + 7 - preferences()->firstDayOfWeek()) % 7;
     QDateTime actualStart = dayOne.addDays(-weekdayCol);
